# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/college/admission/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/college/admission/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "College\\Admission\\": "packages/college/admission/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        College\Admission\Providers\AdmissionServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Admission'  => College\Admission\Facades\Admission::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=College\\AdmissionTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="College\Admission\Providers\AdmissionServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="College\Admission\Providers\AdmissionServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="College\Admission\Providers\AdmissionServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/admission/{modulename}

**User**

    http://path-to-route-folder/user/admission/{modulename}

**Public**

    http://path-to-route-folder/admissions


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/admission/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/admission/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/admission/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/admission/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/admission/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/admission/{modulename}/{slug}
    METHOD: GET