<?php

namespace College\Admission\Policies;

use Litepie\User\Contracts\UserPolicy;
use College\Admission\Models\Admission;

class AdmissionPolicy
{

    /**
     * Determine if the given user can view the admission.
     *
     * @param UserPolicy $user
     * @param Admission $admission
     *
     * @return bool
     */
    public function view(UserPolicy $user, Admission $admission)
    {
        if ($user->canDo('admission.admission.view') && $user->isAdmin()) {
            return true;
        }

        return $admission->user_id == user_id() && $admission->user_type == user_type();
    }

    /**
     * Determine if the given user can create a admission.
     *
     * @param UserPolicy $user
     * @param Admission $admission
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('admission.admission.create');
    }

    /**
     * Determine if the given user can update the given admission.
     *
     * @param UserPolicy $user
     * @param Admission $admission
     *
     * @return bool
     */
    public function update(UserPolicy $user, Admission $admission)
    {
        if ($user->canDo('admission.admission.edit') && $user->isAdmin()) {
            return true;
        }

        return $admission->user_id == user_id() && $admission->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given admission.
     *
     * @param UserPolicy $user
     * @param Admission $admission
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Admission $admission)
    {
        return $admission->user_id == user_id() && $admission->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given admission.
     *
     * @param UserPolicy $user
     * @param Admission $admission
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Admission $admission)
    {
        if ($user->canDo('admission.admission.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given admission.
     *
     * @param UserPolicy $user
     * @param Admission $admission
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Admission $admission)
    {
        if ($user->canDo('admission.admission.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
